@@ -81,7 +81,7 @@ public:
    *
    * Specifying <rows> and <columns> was made optional for KolourPaint.
    */
-  kpColorCellsBase( QWidget *parent, int rows = 0, int columns = 0 );
+  explicit kpColorCellsBase( QWidget *parent, int rows = 0, int columns = 0 );
   ~kpColorCellsBase() override;
 
 private:
